package com.nokia.nfc.app.test.manual.ui;

import javax.microedition.lcdui.*;

import com.nokia.nfc.app.util.Log;
import com.nokia.nfc.app.util.LogListener;

/**
 * View used for displaying the log back buffer using the entire screen
 * excluding status and softkey bars.<p>
 */
public class LogView extends Form implements CommandListener, LogListener {

    private Command backCmd = new Command("Back", Command.BACK, 1);
    
    private Command clearCmd = new Command("Clear", Command.OK, 1);
    
    private Font font;
    
    private ViewHandler viewHandler;
    
    
    public LogView() {
        super("Log");
        viewHandler = ViewHandler.getInstance();
        font = Font.getFont(Font.FACE_PROPORTIONAL, Font.STYLE_PLAIN, Font.SIZE_SMALL);
        setCommandListener(this);
        addCommand(backCmd);
        addCommand(clearCmd);
        String[] lines = Log.getBackBuffer().tail(-1);

        for (int i = 0; i < lines.length; i++) {
            
            if (lines[i] != null) {
                appendLine(lines[i]);   
            }
        }
        
        Log.addListener(this);
    }
    
    private final void appendLine(String line) {
        StringItem si = new StringItem(null, line);
        si.setFont(font);
        si.setLayout(Item.LAYOUT_NEWLINE_BEFORE);
        si.setPreferredSize(getWidth(), si.getPreferredHeight());
        append(si);
        viewHandler.setCurrentItem(si);
    }
    
    /**
     * @see com.nokia.nfc.app.util.LogListener#lineAdded(java.lang.String)
     */
    public void lineAdded(String line) {
        appendLine(line);
    }
    
    public void commandAction(Command c, Displayable d) {
        
        if (c == backCmd) {
            Log.removeListener(this);
            ViewHandler.getInstance().displayPrevious();
        } else if (c == clearCmd) {
            Log.getBackBuffer().clear();
            deleteAll();
        }
    }
    
}
