package com.nokia.nfc.app.test.manual.ui;

import javax.microedition.lcdui.*;

import com.nokia.nfc.app.test.manual.Control;
import com.nokia.nfc.app.test.manual.NFCTest;
import com.nokia.nfc.app.util.Log;
import com.nokia.nfc.app.util.LogLevel;

public class TestSelector extends List implements CommandListener {
    

    private Command exitCmd = new Command("Exit", Command.EXIT, 100);

    private Command selectCmd = new Command("Open", Command.OK, 1);
    
    private Command enableFileLogCmd = new Command("Enable file log", Command.OK, 2);
    
    private Command disableFileLogCmd = new Command("Disable file log", Command.OK, 2);

    private Command enableConsoleLogCmd = new Command("Enable console log", Command.OK, 3);
    
    private Command disableConsoleLogCmd = new Command("Disable console log", Command.OK, 3);
    
    private Command viewLogCmd = new Command("View log", Command.OK, 90);

    private Control ctrl;
    
    private final String[] tests;
    
    
    public TestSelector(Control ctrl, String[] tests) {
        super("Select test", List.IMPLICIT);
        this.ctrl = ctrl;
        this.tests = tests;
        initList();
        addCommand(exitCmd);
        setSelectCommand(selectCmd);
        setCommandListener(this);
        
        if (Log.isUsingFiles()) {
            addCommand(disableFileLogCmd);
        } else {
            addCommand(enableFileLogCmd);
        }
        
        if (Log.isUsingConsole()) {
            addCommand(disableConsoleLogCmd);
        } else {
            addCommand(enableConsoleLogCmd);
        }
        
        addCommand(viewLogCmd);
    }
    
    private final void initList() {
        
        for (int i = 0; i < tests.length; i += 2) {
            append((String) tests[i], null);
        }
    }

    public void commandAction(Command c, Displayable d) {
        
        if (c == exitCmd) {
            ctrl.exit();
        } else if (c == selectCmd) {
            int index = getSelectedIndex();
            open(index);
        } else if (c == enableConsoleLogCmd) {
            ctrl.setConsoleLogging(true, true);
            removeCommand(enableConsoleLogCmd);
            addCommand(disableConsoleLogCmd);
        } else if (c == disableConsoleLogCmd) {
            ctrl.setConsoleLogging(false, true);
            removeCommand(disableConsoleLogCmd);
            addCommand(enableConsoleLogCmd);
        } else if (c == enableFileLogCmd) {
            
            if (ctrl.setFileLogging(true, true)) {
                removeCommand(enableFileLogCmd);
                addCommand(disableFileLogCmd);
            }
            
        } else if (c == disableFileLogCmd) {
            ctrl.setFileLogging(false, true);
            removeCommand(disableFileLogCmd);
            addCommand(enableFileLogCmd);
        } else if (c == viewLogCmd) {
            ViewHandler.getInstance().display(new LogView());
        }
    }
    
    private final void open(int index) {
        
        try {
            String className = completeTestClassName(tests[index * 2 + 1], tests[index * 2]);
            TestForm testForm = (TestForm) Class.forName(className).newInstance();
            testForm.open();
            ViewHandler.getInstance().display(testForm);
        } catch (Exception e) {
            if (LogLevel.level >= Log.ERROR) Log.log("Could not open test view", e);
        }
    }
    
    private static final String completeTestClassName(String src, String testName) {
        StringBuffer tmp = new StringBuffer();
                
        if (src == null) {
            tmp.append(NFCTest.DEFAULT_PACKAGE);
            tmp.append(testName);
        } else {
            int firstDot = src.indexOf('.');
            
            if (firstDot == -1) {
                tmp.append(NFCTest.DEFAULT_PACKAGE);
                tmp.append(src);
            } else if (firstDot == 0) {
                tmp.append(NFCTest.DEFAULT_PACKAGE);
                tmp.append(src.substring(1));
            } else {
                tmp.append(src);
            }
        }
        
        return tmp.toString();
    }

}
