package com.nokia.nfc.app.util;

/**
 * This class is used to hold parameters related to logging.
 * 
 * PTKit2Log uses these parameters to determine whether logging
 * should be performed and at what level.
 * 
 * Log line entries inside PTKit2 have been arranged so that they will
 * always compare logging level to their own level. This allows
 * compiler/obfuscator to remove those lines from the code if logging
 * level is not high enough.
 *
 * PTKit2 jar comes out with two flavours. One containing this class
 * with logging level set to zero (ptkit2.jar). The other version 
 * (ptkit2_log.jar) is compiled with logging level 5. This way the
 * logging code will not be optiomized away during the compilation of
 * ptkit.
 */
public class LogLevel {

    /**
     * Logging level used inside PTKit2 (0-5).
     * 0 : No logging
     * 5 : Maximum logging
     */
    public static int level = 5;
    
    /**
     * Maximum amount of message bytes to print as a hex string. 
     * <code>-1</code> for unlimited.
     */
    public static final int MAX_HEX_LEN = 256;
    
    
    private LogLevel() {
    }
    
}
